@@ -1,21 +1,14 @@
-# Copyright (c) 2015-2016, 2018-2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2015-2016 Ceridwen <ceridwenv@gmail.com>
-# Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
-# Copyright (c) 2018 Anthony Sottile <asottile@umich.edu>
-# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
+from typing import Optional, Set
 
-from astroid import bases
-from astroid import context as contextmod
-from astroid import nodes, util
-from astroid.context import CallContext
+from astroid import nodes
+from astroid.bases import Instance
+from astroid.context import CallContext, InferenceContext
 from astroid.exceptions import InferenceError, NoDefault
+from astroid.util import Uninferable
 
 
 class CallSite:
@@ -43,31 +36,29 @@ class CallSite:
         self.argument_context_map = argument_context_map
         args = callcontext.args
         keywords = callcontext.keywords
-        self.duplicated_keywords = set()
+        self.duplicated_keywords: Set[str] = set()
         self._unpacked_args = self._unpack_args(args, context=context)
         self._unpacked_kwargs = self._unpack_keywords(keywords, context=context)
 
         self.positional_arguments = [
-            arg for arg in self._unpacked_args if arg is not util.Uninferable
+            arg for arg in self._unpacked_args if arg is not Uninferable
         ]
         self.keyword_arguments = {
             key: value
             for key, value in self._unpacked_kwargs.items()
-            if value is not util.Uninferable
+            if value is not Uninferable
         }
 
     @classmethod
-    def from_call(cls, call_node, context=None):
+    def from_call(cls, call_node, context: Optional[InferenceContext] = None):
         """Get a CallSite object from the given Call node.
 
-        :param context:
-            An instance of :class:`astroid.context.Context` that will be used
-            to force a single inference path.
+        context will be used to force a single inference path.
         """
 
         # Determine the callcontext from the given `context` object if any.
-        context = context or contextmod.InferenceContext()
-        callcontext = contextmod.CallContext(call_node.args, call_node.keywords)
+        context = context or InferenceContext()
+        callcontext = CallContext(call_node.args, call_node.keywords)
         return cls(callcontext, context=context)
 
     def has_invalid_arguments(self):
@@ -92,7 +83,7 @@ class CallSite:
 
     def _unpack_keywords(self, keywords, context=None):
         values = {}
-        context = context or contextmod.InferenceContext()
+        context = context or InferenceContext()
         context.extra_context = self.argument_context_map
         for name, value in keywords:
             if name is None:
@@ -100,33 +91,33 @@ class CallSite:
                 try:
                     inferred = next(value.infer(context=context))
                 except InferenceError:
-                    values[name] = util.Uninferable
+                    values[name] = Uninferable
                     continue
                 except StopIteration:
                     continue
 
                 if not isinstance(inferred, nodes.Dict):
                     # Not something we can work with.
-                    values[name] = util.Uninferable
+                    values[name] = Uninferable
                     continue
 
                 for dict_key, dict_value in inferred.items:
                     try:
                         dict_key = next(dict_key.infer(context=context))
                     except InferenceError:
-                        values[name] = util.Uninferable
+                        values[name] = Uninferable
                         continue
                     except StopIteration:
                         continue
                     if not isinstance(dict_key, nodes.Const):
-                        values[name] = util.Uninferable
+                        values[name] = Uninferable
                         continue
                     if not isinstance(dict_key.value, str):
-                        values[name] = util.Uninferable
+                        values[name] = Uninferable
                         continue
                     if dict_key.value in values:
                         # The name is already in the dictionary
-                        values[dict_key.value] = util.Uninferable
+                        values[dict_key.value] = Uninferable
                         self.duplicated_keywords.add(dict_key.value)
                         continue
                     values[dict_key.value] = dict_value
@@ -136,23 +127,23 @@ class CallSite:
 
     def _unpack_args(self, args, context=None):
         values = []
-        context = context or contextmod.InferenceContext()
+        context = context or InferenceContext()
         context.extra_context = self.argument_context_map
         for arg in args:
             if isinstance(arg, nodes.Starred):
                 try:
                     inferred = next(arg.value.infer(context=context))
                 except InferenceError:
-                    values.append(util.Uninferable)
+                    values.append(Uninferable)
                     continue
                 except StopIteration:
                     continue
 
-                if inferred is util.Uninferable:
-                    values.append(util.Uninferable)
+                if inferred is Uninferable:
+                    values.append(Uninferable)
                     continue
                 if not hasattr(inferred, "elts"):
-                    values.append(util.Uninferable)
+                    values.append(Uninferable)
                     continue
                 values.extend(inferred.elts)
             else:
@@ -216,13 +207,17 @@ class CallSite:
                     positional.append(arg)
 
         if argindex is not None:
+            boundnode = getattr(context, "boundnode", None)
             # 2. first argument of instance/class method
-            if argindex == 0 and funcnode.type in ("method", "classmethod"):
-                if context.boundnode is not None:
-                    boundnode = context.boundnode
-                else:
+            if argindex == 0 and funcnode.type in {"method", "classmethod"}:
+                # context.boundnode is None when an instance method is called with
+                # the class, e.g. MyClass.method(obj, ...). In this case, self
+                # is the first argument.
+                if boundnode is None and funcnode.type == "method" and positional:
+                    return positional[0].infer(context=context)
+                if boundnode is None:
                     # XXX can do better ?
-                    boundnode = funcnode.parent.frame()
+                    boundnode = funcnode.parent.frame(future=True)
 
                 if isinstance(boundnode, nodes.ClassDef):
                     # Verify that we're accessing a method
@@ -234,7 +229,7 @@ class CallSite:
                         return iter((boundnode,))
 
                 if funcnode.type == "method":
-                    if not isinstance(boundnode, bases.Instance):
+                    if not isinstance(boundnode, Instance):
                         boundnode = boundnode.instantiate_class()
                     return iter((boundnode,))
                 if funcnode.type == "classmethod":
@@ -242,7 +237,7 @@ class CallSite:
             # if we have a method, extract one position
             # from the index, so we'll take in account
             # the extra parameter represented by `self` or `cls`
-            if funcnode.type in ("method", "classmethod"):
+            if funcnode.type in {"method", "classmethod"} and boundnode:
                 argindex -= 1
             # 2. search arg index
             try:
