@@ -1,16 +1,6 @@
-# Copyright (c) 2016-2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2017 Hugo <hugovk@users.noreply.github.com>
-# Copyright (c) 2018 Peter Talley <peterctalley@gmail.com>
-# Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2020 Peter Pentchev <roam@ringlet.net>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-# Copyright (c) 2021 Damien Baty <damien@damienbaty.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
 import textwrap
 
@@ -93,8 +83,8 @@ def _subprocess_transform():
         """.strip()
 
     code = textwrap.dedent(
-        """
-    def %(check_output_signature)s
+        f"""
+    def {check_output_signature}
         if universal_newlines:
             return ""
         return b""
@@ -102,11 +92,11 @@ def _subprocess_transform():
     class Popen(object):
         returncode = pid = 0
         stdin = stdout = stderr = file()
-        %(py3_args)s
+        {py3_args}
 
-        %(communicate_signature)s:
-            return %(communicate)r
-        %(wait_signature)s:
+        {communicate_signature}:
+            return {communicate!r}
+        {wait_signature}:
             return self.returncode
         def poll(self):
             return self.returncode
@@ -116,16 +106,8 @@ def _subprocess_transform():
             pass
         def kill(self):
             pass
-        %(ctx_manager)s
+        {ctx_manager}
        """
-        % {
-            "check_output_signature": check_output_signature,
-            "communicate": communicate,
-            "communicate_signature": communicate_signature,
-            "wait_signature": wait_signature,
-            "ctx_manager": ctx_manager,
-            "py3_args": py3_args,
-        }
     )
     if PY39_PLUS:
         code += """
