@@ -1,5 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
 """Transform utilities (filters and decorator)"""
 
@@ -7,12 +8,18 @@ import typing
 
 import wrapt
 
-from astroid.exceptions import InferenceOverwriteError
+from astroid import bases, util
+from astroid.exceptions import InferenceOverwriteError, UseInferenceDefault
 from astroid.nodes import NodeNG
+from astroid.typing import InferFn
 
-InferFn = typing.Callable[..., typing.Any]
+InferOptions = typing.Union[
+    NodeNG, bases.Instance, bases.UnboundMethod, typing.Type[util.Uninferable]
+]
 
-_cache: typing.Dict[typing.Tuple[InferFn, NodeNG], typing.Any] = {}
+_cache: typing.Dict[
+    typing.Tuple[InferFn, NodeNG], typing.Optional[typing.List[InferOptions]]
+] = {}
 
 
 def clear_inference_tip_cache():
@@ -21,13 +28,21 @@ def clear_inference_tip_cache():
 
 
 @wrapt.decorator
-def _inference_tip_cached(func, instance, args, kwargs):
+def _inference_tip_cached(
+    func: InferFn, instance: None, args: typing.Any, kwargs: typing.Any
+) -> typing.Iterator[InferOptions]:
     """Cache decorator used for inference tips"""
     node = args[0]
     try:
         result = _cache[func, node]
+        # If through recursion we end up trying to infer the same
+        # func + node we raise here.
+        if result is None:
+            raise UseInferenceDefault()
     except KeyError:
+        _cache[func, node] = None
         result = _cache[func, node] = list(func(*args, **kwargs))
+        assert result
     return iter(result)
 
 
